==> haskell-ansi-terminal-0.7.1.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ansi-terminal
version: 0.7.1.1
id: ansi-terminal-0.7.1.1-Dh7XzY8d9TAbWhL1ZsstE
key: ansi-terminal-0.7.1.1-Dh7XzY8d9TAbWhL1ZsstE
license: BSD3
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/ansi-terminal
synopsis: Simple ANSI terminal support, with Windows compatibility
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.
category: User Interfaces
author: Max Bolingbroke
exposed: True
indefinite: False
exposed-modules:
    System.Console.ANSI System.Console.ANSI.Codes
    System.Console.ANSI.Types
hidden-modules: System.Console.ANSI.Unix
abi: d9f2a1ce1d226f75ea8fb44a88f58b7b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/ansi-terminal-0.7.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/ansi-terminal-0.7.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/ansi-terminal-0.7.1.1
hs-libraries: HSansi-terminal-0.7.1.1-Dh7XzY8d9TAbWhL1ZsstE
depends:
    base-4.10.1.0 colour-2.3.4-4FOR755TjbXCteGD5Oe26Q
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             colour-2.3.4-4FOR755TjbXCteGD5Oe26Q=5a3580e6fb04cd83bff9a9ebb80037e2
haddock-interfaces: /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ansi-terminal-0.7.1.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ansi-terminal
version: 0.7.1.1
id: ansi-terminal-0.7.1.1-G9WTxmkEIHS8T5XM1ZnzRT
key: ansi-terminal-0.7.1.1-G9WTxmkEIHS8T5XM1ZnzRT
license: BSD3
maintainer: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/ansi-terminal
synopsis: Simple ANSI terminal support, with Windows compatibility
description:
    ANSI terminal support for Haskell: allows cursor movement,
    screen clearing, color output, showing or hiding the
    cursor, and changing the title. Works on UNIX and Windows.
category: User Interfaces
author: Max Bolingbroke
exposed: True
indefinite: False
exposed-modules:
    System.Console.ANSI System.Console.ANSI.Codes
    System.Console.ANSI.Types
hidden-modules: System.Console.ANSI.Unix
abi: 0aa3d84ed37feddcfc4971478d436776
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/ansi-terminal-0.7.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/ansi-terminal-0.7.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/ansi-terminal-0.7.1.1
hs-libraries: HSansi-terminal-0.7.1.1-G9WTxmkEIHS8T5XM1ZnzRT
depends:
    base-4.10.1.0 colour-2.3.4-3MiiEznBxpfEYrMTHbnSer
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             colour-2.3.4-3MiiEznBxpfEYrMTHbnSer=17ebf8ef9f22d84631cb99a648619ec0
haddock-interfaces: /usr/share/doc/haskell-ansi-terminal/html/ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
